@@ -127,6 +127,8 @@ EXTENSIONS = {
     'py': {'text', 'python'},
     'pyi': {'text', 'pyi'},
     'pyx': {'text', 'cython'},
+    'pyz': {'binary', 'pyz'},
+    'pyzw': {'binary', 'pyz'},
     'pxd': {'text', 'cython'},
     'pxi': {'text', 'cython'},
     'r': {'text', 'r'},
